#read in equilibrium cost shares from CC02.txt file into W matrix
BEGIN {j=1;}
{
    # n is the number of commodities
    n=split($0,tmp); # split row of data into array tmp
    for (i=1; i<=n; i++) {
	W[i,j]=tmp[i];
	rowsum[i]+=W[i,j]; #keep track of row sums
    }
    j++;
}
# now calculate c_n coefficients
END {
    # add a "labor" sector to this economy
    for (i=1; i<=n; i++) {
	W[i,n+1]=1.-rowsum[i]; # cost share not assigned to commodities are assigned to labor
    }
    # set up inputs for the "production" of labor
    # assume commodities overall make up 75% of input to labor
    fl=0.75;
    for (j=1; j<=n; j++) {
	W[n+1,j]=fl/n; #split contribution of each sector evenly
    }
    w[n+1,n+1]=1-fl; #set labor input cost share into production of labor
    # labor now added, increment number of sectors by one
    n++;
    # read in which industries (group of sectors) we want to aggregate over from sect.in
    while (getline < "sect.in") {
	aggsec=$1;
	print "sec: " aggsec;
	# look for industries whose name match the same starting string as aggsec
	for (j=1; j<=n; j++) {
	    getline < "name.out"; # read in industry names from file
	    secnum[j]=substr($1 "",1,length(aggsec));
	}
	close("name.out");

	tmax=15; # maximum path length considered
	# initialize c_n to 0 
	# here t is the same as the "n" in "c_n" in the paper
	for (t=1; t<=tmax; t++) {
	    c[t]=0.;
	}
	# initialize to 0 the vector v that will accumulate the matrix products
	for (j=1; j<=n; j++) {v[j]=0.;}
	# set to 1 sectors part of the industry of interest (e^o in the paper)
	i0=1;
	while (secnum[i0]!=aggsec) {i0++;} #skip sectors not in industry
	for (; secnum[i0]==aggsec; i0++) {
	    v[i0]=1.; #mark section as part of industry
	}
	# compute W^t e^o for t=1 to tmax by iterating the map W*v -> v
	for (t=1; t<=tmax; t++) {
	    # calc matrix product newv= W*v
	    for (i=1; i<=n; i++) {
		newv[i]=0;
		for (j=1; j<=n; j++) {
		    newv[i]+=W[i,j]*v[j];
		}
	    }
	    for (i=1; i<=n; i++) {v[i]=newv[i];} #v=newv
	    # calc c_n = e^d' * v ( which is = e^d' * W^n * e^o )
	    for (j=1; j<=n; j++) {
		if (secnum[j]==aggsec) {
		    c[t]+=v[j];
		}
	    }
	}
	# output the c_n in a file
	file="plotmatseclab_" aggsec ".out";
	for (t=1; t<=tmax; t++) {
	    print t,c[t] > file;
	}
	close(file);
    }
}
